==> v1.0.0.tar.gz: lxd-dashboard/admin/php/lxd/project-list.php <==
<?php

$cert = "/root/.config/lxc/client.crt";
$key = "/root/.config/lxc/client.key";

if (isset($_GET['remote']))
  $remote = filter_var(urldecode($_GET['remote']), FILTER_SANITIZE_STRING);
if (isset($_GET['project']))
  $project = filter_var(urldecode($_GET['project']), FILTER_SANITIZE_STRING);

$db = new SQLite3('/var/lxdware/data/sqlite/lxdware.sqlite');
$db_statement = $db->prepare('SELECT * FROM lxd_hosts WHERE id = :id LIMIT 1;');
$db_statement->bindValue(':id', $remote);
$db_results = $db_statement->execute();

while($row = $db_results->fetchArray()){
  $url = "https://" . $row['host'] . ":" . $row['port'] . "/1.0/projects";
  $remote_data = shell_exec("sudo curl -k -L --cert $cert --key $key -X GET $url");
  $remote_data = json_decode($remote_data, true);
  $project_urls = $remote_data['metadata'];

  $i = 0;
  echo '{ "data": [';

  foreach ($project_urls as $project_url){
    $url = "https://" . $row['host'] . ":" . $row['port'] . $project_url;
    $project_data = shell_exec("sudo curl -k -L --cert $cert --key $key -X GET $url");
    $project_data = json_decode($project_data, true);
    $project_data = $project_data['metadata'];

    if ($i > 0){
      echo ",";
    }
    $i++;

    echo "[ ";
    echo '"';
    echo "<a href='host.html?remote=".$remote."&project=".$project_data['name'] ."'><i class='fas fa-project-diagram fa-lg' style='color:#4e73df'></i> </a>";
    echo '",';

    echo '"';
    echo "<a href='host.html?remote=".$remote."&project=".$project_data['name'] ."'> ".htmlentities($project_data['name']) ."</a>";
    echo '",';

    echo '"' . htmlentities($project_data['description']) . '",';
    echo '"' . htmlentities($project_data['config']['features.images']) . '",';
    echo '"' . htmlentities($project_data['config']['features.profiles']) . '",';
    echo '"' . htmlentities($project_data['config']['features.storage.volumes']) . '",';


    echo '"';
      echo "<div class='dropdown no-arrow'>";
      echo "<a class='dropdown-toggle' href='#' role='button' id='dropdownMenuLink' data-toggle='dropdown' aria-haspopup='true' aria-expanded='false'>";
      echo "<i class='fas fa-ellipsis-v fa-lg fa-fw text-gray-400'></i>";
      echo "</a>";
      echo "<div class='dropdown-menu dropdown-menu-right shadow animated--fade-in' aria-labelledby='dropdownMenuLink'>";
      echo "<div class='dropdown-header'>Options:</div>";
      echo "<a class='dropdown-item' href='#' onclick=loadProjectJson('".$project_data['name']."')>Edit</a>";
      echo "<a class='dropdown-item' href='#' onclick=deleteProject('".$project_data['name']."')>Delete</a>";
      echo "</div>";
      echo "</div>";
    echo '"';

    echo " ]";

  }

  echo " ]}";
  
}

?>

==> v1.0.7.tar.gz: lxd-dashboard/admin/php/lxd/project-list.php <==
<?php

$cert = "/root/.config/lxc/client.crt";
$key = "/root/.config/lxc/client.key";

if (isset($_GET['remote']))
  $remote = filter_var(urldecode($_GET['remote']), FILTER_SANITIZE_STRING);
if (isset($_GET['project']))
  $project = filter_var(urldecode($_GET['project']), FILTER_SANITIZE_STRING);

$db = new SQLite3('/var/lxdware/data/sqlite/lxdware.sqlite');
$db_statement = $db->prepare('SELECT * FROM lxd_hosts WHERE id = :id LIMIT 1;');
$db_statement->bindValue(':id', $remote);
$db_results = $db_statement->execute();

while($row = $db_results->fetchArray()){
  $url = "https://" . $row['host'] . ":" . $row['port'] . "/1.0/projects";
  $remote_data = shell_exec("sudo curl -k -L --cert $cert --key $key -X GET $url");
  $remote_data = json_decode($remote_data, true);
  $project_urls = $remote_data['metadata'];

  $i = 0;
  echo '{ "data": [';

  foreach ($project_urls as $project_url){
    $url = "https://" . $row['host'] . ":" . $row['port'] . $project_url;
    $project_data = shell_exec("sudo curl -k -L --cert $cert --key $key -X GET $url");
    $project_data = json_decode($project_data, true);
    $project_data = $project_data['metadata'];

    if ($i > 0){
      echo ",";
    }
    $i++;

    echo "[ ";
    echo '"';
    echo "<a href='host.html?remote=".$remote."&project=".$project_data['name'] ."'><i class='fas fa-project-diagram fa-lg' style='color:#4e73df'></i> </a>";
    echo '",';

    echo '"';
    echo "<a href='host.html?remote=".$remote."&project=".$project_data['name'] ."'> ".htmlentities($project_data['name']) ."</a>";
    echo '",';

    echo '"' . htmlentities($project_data['description']) . '",';
    echo '"' . htmlentities($project_data['config']['features.images']) . '",';
    echo '"' . htmlentities($project_data['config']['features.profiles']) . '",';
    echo '"' . htmlentities($project_data['config']['features.storage.volumes']) . '",';


    echo '"';
      echo "<div class='dropdown no-arrow'>";
      echo "<a class='dropdown-toggle' href='#' role='button' id='dropdownMenuLink' data-toggle='dropdown' aria-haspopup='true' aria-expanded='false'>";
      echo "<i class='fas fa-ellipsis-v fa-sm fa-fw text-gray-400'></i>";
      echo "</a>";
      echo "<div class='dropdown-menu dropdown-menu-right shadow animated--fade-in' aria-labelledby='dropdownMenuLink'>";
      echo "<div class='dropdown-header'>Options:</div>";
      echo "<a class='dropdown-item' href='#' onclick=loadProjectJson('".$project_data['name']."')>Edit</a>";
      echo "<a class='dropdown-item' href='#' onclick=deleteProject('".$project_data['name']."')>Delete</a>";
      echo "</div>";
      echo "</div>";
    echo '"';

    echo " ]";

  }

  echo " ]}";
  
}

?>
